Learn R Programming

superspreading (version 0.4.0)

ppoisweibull: Cumulative distribution function of the Poisson-Weibull compound distribution

Description

Cumulative distribution function of the Poisson-Weibull compound distribution

Usage

ppoisweibull(q, shape, scale)

Value

A numeric vector of the distribution function.

Arguments

q

A number for the quantile of the distribution.

shape

A number for the shape parameter of the distribution.

scale

A number for the scale parameter of the distribution.

Details

The function is vectorised so a vector of quantiles can be input and the output will have an equal length.

Examples

Run this code
ppoisweibull(q = 10, shape = 1, scale = 2)
ppoisweibull(q = 1:10, shape = 1, scale = 2)

Run the code above in your browser using DataLab