powered by
Cumulative distribution function of the Poisson-Weibull compound distribution
ppoisweibull(q, shape, scale)
A numeric vector of the distribution function.
numeric
A number for the quantile of the distribution.
number
A number for the shape parameter of the distribution.
A number for the scale parameter of the distribution.
The function is vectorised so a vector of quantiles can be input and the output will have an equal length.
ppoisweibull(q = 10, shape = 1, scale = 2) ppoisweibull(q = 1:10, shape = 1, scale = 2)
Run the code above in your browser using DataLab